/**
 * 水上客运地图功能组件，通过调用封装好的基础地图组件实现特定业务功能
 */
import { fullExtent, clearMap, calculation, changeMap, setCamera,
    layerControl, layerQuery, addGraphic, draw, getDrawGeometry,
    addBoats, addBoatHistory
} from '@/utils/map/ArcgisUtil'

import {GetPjylLinePaths} from "@/apis/ssky";
import {GetHpjShip} from "@/apis/ship";

let showBoat = false;
let djldInterval;

// 浦江游览航线
export function pjylLine(){
    GetPjylLinePaths().then(res=>{
        for (let i=0;i<res.data.length;i++){
            let lineData = res.data[i]
            let linePoints = lineData.linePoints
            let points = []
            let first = []
            for(let j=0;j<linePoints.length;j++){
                let point = [Number(linePoints[j].x),Number(linePoints[j].y)]
                if(j==0){
                    first = [Number(linePoints[j].x),Number(linePoints[j].y)]
                }
                points.push(point)
            }
            points.push(first)

            let params = {
                // title: res.data[i].get('lineName'),
                type: 'polygon',
                data: points,
                edit: false,
                temp: true,
                clear: false,
                goto: true,
                attributes: null,
                symbol: {
                    type: "simple-fill",
                    color: [50, 205, 50, 0.5],
                    //style: "cross",
                    outline: {
                        color: [255, 0, 0],
                        width: 2
                    }
                }
            }
            // 绘制到地图上
            addGraphic(params)
        }
    })
}

// 浦江游览
// 浦江游览码头定位
export function pjylPortLocation(data){
    // 码头定位
    let param = {
        title: data.portName,
        type: 'point',
        data:[data.mapx,data.mapy,20],
        edit: false,
        temp: true,
        clear: false,
        goto: true,
        attributes: null,
        symbol:{
            "type": "picture-marker",
            "url": "images/ssky/bgImgPort.png",
            "width":"300px",
            "height":"10px"
        }
    }
    addGraphic(param)
    // 绘制陆域围栏
    layerQuery({
        title: "waterPassenger",
        layerId: "4",
        where: "码头名称='" + data.portName +"'",
        symbol: null,
        is_draw: true,
        is_clear: false,
        callback: "pjylPortHandle"
    })
}
// 浦江游览码头查询回调
export function pjylPortHandle(res) {
    let data = res.data[0].geometry.rings[0]
    console.log("浦江游览码头回调结果："+data)
    let params = {
        type: 'line-3d',
        data: data,
        edit: false,
        temp: true,
        clear: false,
        goto: true,
        attributes: null,
        title: null
    }
    addGraphic(params)
}

// 对江轮渡船舶撒点
export function djldShip(){
    if(!showBoat)
        showBoat = true
    onLocationDjldBoat()
    if(djldInterval!=null){
        clearInterval(djldInterval)
    }
    djldInterval = setInterval(onLocationDjldBoat,10000)
}

export function onLocationDjldBoat(){
    GetHpjShip().then(res=>{
        let data = res.Result.data
        let boats = {
            "scale": 5000,
            "goto": false,
            "data": []
        }
        for(let i=0;i<data.length;i++){
            if(data[i].LINETYPE == 'djld'){
                let boat = {
                    "mmsi": data[i].DEVICEID,
                    "shipNameCn": data[i].BOATNAME,
                    "shipTypeName": data[i].SHIPTYPENAME,
                    "direction": data[i].DIRECTION,
                    "velocity": data[i].VELOCITY,
                    "shipBreadth": data[i].SHIPBREADTH,
                    "shipLength": data[i].SHIPLENGTH,
                    "mapx": data[i].MAPX,
                    "mapy": data[i].MAPY
                }
                boats.data.push(boat)
            }
        }
        addBoats(boats)
    })
}